Page 41 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 41

Home

    Although ignored by most historians, especially those
    who wished to glorify the leaders of the Revolution, the
    truth was recorded by all factions, and preserved in

    primary source documents. These documents have been
    available to all who wished to present the truth about this

    dark period in world history.

    Lord Acton said, "The appalling thing in the French
    Revolution is not the tumult but the design."? The design
    that is apparent throughout the Revolution is Adam
    Weishaupt's plan to destroy all religion, overthrow all

    Tragically, the Revolution began at a time when great
    progress was being made toward the reforms sought by
    the people. The force behind the movement for reform
    was not the revolutionaries, but King Louis XVI.

    To ascertain the wishes of the people, a proclamation
    had been sent out by the King to the whole nation saying:

    His Majesty has desired that in the extremities of his
    kingdom and in the obscurest dwellings every man shall
    rest assured that his wishes and requests shall be heard.*

    the country were compiled in what was known as the
    "cahiers." The contents of the cahiers were summed up

    36

    The Secret Side of History

    governments, and rule the world.

    The lists of grievances that arrived from all parts of

    by Hua that:

    The voice of the nation cried out for reform, for changes in

    the government, but all proclaimed respect